@@ -1,7 +1,7 @@
 package Getopt::Long::Less;
 
-our $DATE = '2016-12-02'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-12-03'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -383,7 +383,7 @@ Getopt::Long::Less - Like Getopt::Long, but with less features
 
 =head1 VERSION
 
-This document describes version 0.07 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2016-12-02.
+This document describes version 0.08 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2016-12-03.
 
 =head1 DESCRIPTION
 
@@ -418,15 +418,15 @@ milliseconds from startup overhead of my CLI scripts. That's it :-)
 
 Sample startup overhead benchmark:
 
-                      Rate    load_gl load_glless   perl
- load_gl     68.78+-0.66/s         --      -43.6% -87.8%
- load_glless    122+-2.1/s 77.4+-3.5%          -- -78.4%
- perl           566+-7.9/s   723+-14%    364+-10%     --
+                      Rate     load_gl load_glless   perl
+ load_gl     77.72+-0.25/s          --      -42.4% -86.9%
+ load_glless   135+-0.28/s 73.7+-0.67%          -- -77.3%
+ perl         594.5+-2.1/s   665+-3.7% 340.4+-1.8%     --
  
  Average times:
-   perl       :     1.7668ms
-   load_glless:     8.1967ms
-   load_gl    :    14.5391ms
+   perl       :     1.6821ms
+   load_glless:     7.4074ms
+   load_gl    :    12.8667ms
 
 =for Pod::Coverage .+
 
@@ -450,6 +450,8 @@ feature.
 
 L<Getopt::Long>
 
+If you want I<more> features intead of less, try L<Getopt::Long::More>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
